function h = errorbarplot(bar_x, err_srs, data_x, data, varargin)
%put in [] for bar_x if err_srs and data are the same length and you want bars at every point; otherwise, this assumes that data_x is uniform.
%err_srs can either be the same dimensionality as data_x, in which case it's +/- that value, or one dimension higher, with the last dimension of size 2, giving raw values

if size(err_srs, 1) == 1
    err_srs = err_srs';
end
if size(data_x, 1) == 1
    data_x = data_x';
end
if size(data, 1) == 1
    data = data';
end

if nrealdims(err_srs) == nrealdims(data)
    err_srs = cat(nrealdims(err_srs)+1, data-err_srs, data+err_srs);
end

color_arg = find(cellfun(@(x) strcmp(x, 'Color'), varargin));

h = plot(data_x, data, varargin{:});

if isempty(color_arg)
    eb_colors = get(h, 'Color');
else
    eb_colors = varargin{color_arg+1};
end

bw = (max(xlim) - min(xlim))/200;

if length(data_x) == 1
    if isempty(bar_x)
        bar_x = data_x;
    end
    line(repmat([bar_x bar_x], [length(data) 1]), err_srs, -1 * ones(2, size(data, 2)), 'Color', eb_colors);
    line(repmat([bar_x-bw bar_x+bw], [length(data) 1]), [err_srs(1) err_srs(1)], -1 * ones(2, size(data, 2)), 'Color', eb_colors);
    line(repmat([bar_x-bw bar_x+bw], [length(data) 1]), [err_srs(2) err_srs(2)], -1 * ones(2, size(data, 2)), 'Color', eb_colors);
    return
end

% bar_y = cat_means(round(((0:n_cats-1)*.01 + .1)*sr) + size(data,1)*(0:size(data,2)-1));
if ~isempty(bar_x)
% 	bar_y = data(round((bar_x - data_x(1)) * (size(data,1)-1) / (data_x(end) - data_x(1)))+1, :);
% 	bar_h = err_srs(round((bar_x - data_x(1)) * (size(data,1)-1) / (data_x(end) - data_x(1)))+1, :);
else
    if ndims(err_srs)==2
        bar_y1 = err_srs(:, 1);
        bar_y2 = err_srs(:, 2);
    elseif ndims(err_srs)==3
        bar_y1 = err_srs(:, :, 1);
        bar_y2 = err_srs(:, :, 2);
    end
	bar_x = data_x;
end

for data_series = 1:size(data, 2)
    if isempty(color_arg) && size(data,2)>1
       this_color = eb_colors{data_series};
    else
        this_color = eb_colors;
    end
    for b = 1:length(bar_x)
        line([bar_x(b); bar_x(b)], [bar_y1(b,data_series); bar_y2(b,data_series)], [-1; -1], 'Color', this_color);
        line([bar_x(b)-bw; bar_x(b)+bw], [bar_y1(b,data_series); bar_y1(b,data_series)], [-1; -1], 'Color', this_color);
        line([bar_x(b)-bw; bar_x(b)+bw], [bar_y2(b,data_series); bar_y2(b,data_series)], [-1; -1], 'Color', this_color);
    end
end
% line([(0:n_cats-1)*.01; (0:n_cats-1)*.01], [bar_y + cat_sems; bar_y - cat_sems]);
end

function nrd = nrealdims(x)
nrd = sum(size(x) > 1);
end